<?php
/* Smarty version {Smarty::SMARTY_VERSION}, created on 2019-06-05 10:24:32
  from "ls:viewSearch.tpl" */

/* @var Smarty_Internal_Template $_smarty_tpl */
if ($_smarty_tpl->_decodeProperties($_smarty_tpl, array (
  'version' => '3.1.31',
  'unifunc' => 'content_5cf798604dab55_89119269',
  'has_nocache_code' => false,
  'file_dependency' => 
  array (
    '7e5e1b40a6897e6cd2a4b75f034a469f40dd849c' => 
    array (
      0 => 'ls:viewSearch.tpl',
      1 => 1559564613,
      2 => 'ls',
    ),
  ),
  'includes' => 
  array (
    'ls:top.tpl' => 1,
    'ls:bottom.tpl' => 1,
  ),
),false)) {
function content_5cf798604dab55_89119269 (Smarty_Internal_Template $_smarty_tpl) {
if (!is_callable('smarty_function_html_options')) require_once '/usr/share/php/smarty3/plugins/function.html_options.php';
if (!is_callable('smarty_function_cycle')) require_once '/usr/share/php/smarty3/plugins/function.cycle.php';
$_smarty_tpl->_subTemplateRender('ls:top.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
?>

<form action='<?php echo $_smarty_tpl->tpl_vars['searchForm']->value['action'];?>
' method='post' class='LSview_search' id='LSsearch_form'>

<div class='LSview_search'>
  <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['searchForm']->value['hiddenFields'], 'value', false, 'name');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['name']->value => $_smarty_tpl->tpl_vars['value']->value) {
?>
    <input type='hidden' name='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['name']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['value']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' />
  <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

  
  <input type='text' name='pattern' class='LSview_search' value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['searchForm']->value['values']['pattern'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/>
  <input type='submit' value='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['searchForm']->value['labels']['submit'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' name='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['searchForm']->value['names']['submit'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' class='LSview_search' />
  <p id='LSview_search_param'>
    <label class='LSview_search'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['searchForm']->value['labels']['approx'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 : <input type='checkbox' name='approx' class='LSview_search' <?php if ($_smarty_tpl->tpl_vars['searchForm']->value['values']['approx'] != '') {?>checked="true"<?php }?> /></label>
    <?php if ($_smarty_tpl->tpl_vars['searchForm']->value['recursive']) {?><label class='LSview_search'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['searchForm']->value['labels']['recursive'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
 : <input type='checkbox' name='recursive' class='LSview_search' <?php if ($_smarty_tpl->tpl_vars['searchForm']->value['values']['recursive'] != '') {?>checked="true"<?php }?>/></label><?php }?>
  </p>
</div>

<h1>
  <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['pagetitle']->value, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

</h1>

<?php if ($_smarty_tpl->tpl_vars['LSview_actions']->value != '') {?>
<ul class='LSview-actions'>
  <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSview_actions']->value, 'item');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['item']->value) {
?>
    <?php if (is_array($_smarty_tpl->tpl_vars['item']->value)) {?>
      <li class='LSview-actions'><a href='<?php echo $_smarty_tpl->tpl_vars['item']->value['url'];?>
' class='LSview-actions'><img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' /> <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</a></li>
    <?php }?>
  <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

</ul>
<?php }?>

<?php if (count($_smarty_tpl->tpl_vars['LSsearch']->value->predefinedFilters) != 0) {?>
  <select id='LSview_search_predefinedFilter' name='predefinedFilter'>
    <option value=''>--</option>
    <?php echo smarty_function_html_options(array('options'=>$_smarty_tpl->tpl_vars['LSsearch']->value->predefinedFilters,'selected'=>$_smarty_tpl->tpl_vars['searchForm']->value['predefinedFilter']),$_smarty_tpl);?>

  </select>
<?php }?>


</form>

<table class='LSobject-list'>
    <tr class='LSobject-list'>
      <th class='LSobject-list'>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sort) {?>
        <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;sortBy=displayName&amp;nocache=<?php echo time();?>
'>
          <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sortBy == 'displayName') {?>
            <strong><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_objectName, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</strong>
            <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection),$_smarty_tpl);?>
' class='LSobject-list-ordersense' alt='<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection;?>
'/>
          <?php } else { ?>
            <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_objectName, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

          <?php }?>
        </a>
        <?php } else { ?>
          <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_objectName, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

        <?php }?>
      </th>
      <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->displaySubDn) {?>
        <th class='LSobject-list LSobject-list-subdn'>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sort) {?>
          <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;sortBy=subDn&amp;nocache=<?php echo time();?>
'>
          <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sortBy == 'subDn') {?>
            <strong><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_level, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</strong>
            <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection),$_smarty_tpl);?>
' class='LSobject-list-ordersense' alt='<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection;?>
'/>
          <?php } else { ?>
            <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_level, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

          <?php }?>
          </a>
        <?php } else { ?>
          <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_level, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

        <?php }?>
        </th>
      <?php }?>
      <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {?>
        <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSsearch']->value->visibleExtraDisplayedColumns, 'conf', false, 'cid');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['cid']->value => $_smarty_tpl->tpl_vars['conf']->value) {
?>
        <th class='LSobject-list'<?php if ($_smarty_tpl->tpl_vars['conf']->value['cssStyle']) {?> style='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['conf']->value['cssStyle'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'<?php }?>>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sort) {?>
          <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;sortBy=<?php echo rawurlencode($_smarty_tpl->tpl_vars['cid']->value);?>
&amp;nocache=<?php echo time();?>
'>
          <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->sortBy == $_smarty_tpl->tpl_vars['cid']->value) {?>
            <strong><?php echo LStemplate_smarty_tr(array('msg'=>mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['conf']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8')),$_smarty_tpl);?>
</strong>
            <img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection),$_smarty_tpl);?>
' class='LSobject-list-ordersense' alt='<?php echo $_smarty_tpl->tpl_vars['LSsearch']->value->sortDirection;?>
'/>
          <?php } else { ?>
            <?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['conf']->value['label']),$_smarty_tpl);?>

          <?php }?>
          </a>
        <?php } else { ?>
          <?php echo LStemplate_smarty_tr(array('msg'=>$_smarty_tpl->tpl_vars['conf']->value['label']),$_smarty_tpl);?>

        <?php }?>
        </th>
        <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

      <?php }?>
      <th class='LSobject-list'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_actions, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</th>
    </tr>
    <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['page']->value['list'], 'object');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['object']->value) {
?>
    <tr class='<?php echo smarty_function_cycle(array('values'=>"LSobject-list,LSobject-list LSobject-list-bis"),$_smarty_tpl);?>
'>
        <td class='LSobject-list LSobject-list-names'><a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;dn=<?php echo rawurlencode($_smarty_tpl->tpl_vars['object']->value->dn);?>
'  class='LSobject-list'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['object']->value->displayName, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</a> </td>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->displaySubDn) {?><td class='LSobject-list'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['object']->value->subDn, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</td><?php }?>
        <?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {?>
          <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['LSsearch']->value->visibleExtraDisplayedColumns, 'conf', false, 'cid');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['cid']->value => $_smarty_tpl->tpl_vars['conf']->value) {
?>
          <td class='LSobject-list'<?php if ($_smarty_tpl->tpl_vars['conf']->value['cssStyle']) {?> style='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['conf']->value['cssStyle'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'<?php }?>><?php if (!isset($_smarty_tpl->tpl_vars['conf']->value['escape']) || $_smarty_tpl->tpl_vars['conf']->value['escape']) {
echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['object']->value->{$_smarty_tpl->tpl_vars['cid']->value}, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');
} else {
echo $_smarty_tpl->tpl_vars['object']->value->{$_smarty_tpl->tpl_vars['cid']->value};
}?></td>
          <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

        <?php }?>
        <td class='LSobject-list LSobject-list-actions'>
        <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, $_smarty_tpl->tpl_vars['object']->value->actions, 'item');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['item']->value) {
?>
          <a href='<?php echo $_smarty_tpl->tpl_vars['item']->value['url'];?>
'  class='LSobject-list-actions'><img src='<?php echo LStemplate_smarty_img(array('name'=>$_smarty_tpl->tpl_vars['item']->value['action']),$_smarty_tpl);?>
' alt='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
' title='<?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['item']->value['label'], ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
'/></a>
        <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

        </td>
    </tr>
    <?php
}
} else {
?>

      <tr class='LSobject-list'>
        <td colspan='<?php if ($_smarty_tpl->tpl_vars['LSsearch']->value->extraDisplayedColumns) {
echo count($_smarty_tpl->tpl_vars['LSsearch']->value->visibleExtraDisplayedColumns)+3;
} else { ?>3<?php }?>' class='LSobject-list-without-result'>
          <?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_no_result, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>

        </td>
      </tr>   
    <?php
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

</table>
<span id='LSobject_list_nbresult'><?php echo mb_convert_encoding(htmlspecialchars($_smarty_tpl->tpl_vars['LSsearch']->value->label_total, ENT_QUOTES, 'UTF-8', true), "HTML-ENTITIES", 'UTF-8');?>
</span>
<?php if ($_smarty_tpl->tpl_vars['page']->value['nbPages'] > 1) {?>
  <p class='LSobject-list-page'>
    
  <?php if ($_smarty_tpl->tpl_vars['page']->value['nbPages'] > 10) {?>
    <?php if ($_smarty_tpl->tpl_vars['page']->value['nb'] > 5) {?>
      <?php if ($_smarty_tpl->tpl_vars['page']->value['nb'] > $_smarty_tpl->tpl_vars['page']->value['nbPages']-6) {?>
        <?php $_smarty_tpl->_assignInScope('start', $_smarty_tpl->tpl_vars['page']->value['nbPages']-12);
?>
       <?php } else { ?>
        <?php $_smarty_tpl->_assignInScope('start', $_smarty_tpl->tpl_vars['page']->value['nb']-6);
?>
      <?php }?>
    <?php } else { ?>
      <?php $_smarty_tpl->_assignInScope('start', 0);
?>
    <?php }?>
    <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;page=0' class='LSobject-list-page'>&lt;</a>
    <?php
$_from = $_smarty_tpl->smarty->ext->_foreach->init($_smarty_tpl, range(0,10), 'i');
if ($_from !== null) {
foreach ($_from as $_smarty_tpl->tpl_vars['i']->value) {
?>
      <?php if ($_smarty_tpl->tpl_vars['page']->value['nb'] == $_smarty_tpl->tpl_vars['start']->value+$_smarty_tpl->tpl_vars['i']->value) {?>
        <strong class='LSobject-list-page'><?php echo $_smarty_tpl->tpl_vars['page']->value['nb']+1;?>
</strong> 
      <?php } else { ?>
        <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;page=<?php echo $_smarty_tpl->tpl_vars['i']->value+$_smarty_tpl->tpl_vars['start']->value;?>
'  class='LSobject-list-page'><?php echo $_smarty_tpl->tpl_vars['i']->value+$_smarty_tpl->tpl_vars['start']->value+1;?>
</a>
      <?php }?>
    <?php
}
}
$_smarty_tpl->smarty->ext->_foreach->restore($_smarty_tpl, 1);
?>

    <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;page=<?php echo $_smarty_tpl->tpl_vars['page']->value['nbPages']-1;?>
' class='LSobject-list-page'>&gt;</a>
  <?php } else { ?>
    <?php
$__section_listpage_0_saved = isset($_smarty_tpl->tpl_vars['__smarty_section_listpage']) ? $_smarty_tpl->tpl_vars['__smarty_section_listpage'] : false;
$__section_listpage_0_loop = (is_array(@$_loop=$_smarty_tpl->tpl_vars['page']->value['nbPages']) ? count($_loop) : max(0, (int) $_loop));
$__section_listpage_0_total = min(($__section_listpage_0_loop - 0), $__section_listpage_0_loop);
$_smarty_tpl->tpl_vars['__smarty_section_listpage'] = new Smarty_Variable(array());
if ($__section_listpage_0_total != 0) {
for ($__section_listpage_0_iteration = 1, $_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index'] = 0; $__section_listpage_0_iteration <= $__section_listpage_0_total; $__section_listpage_0_iteration++, $_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index']++){
?>
      <?php if ($_smarty_tpl->tpl_vars['page']->value['nb'] == (isset($_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index']) ? $_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index'] : null)) {?>
        <strong class='LSobject-list-page'><?php echo $_smarty_tpl->tpl_vars['page']->value['nb']+1;?>
</strong> 
      <?php } else { ?>
        <a href='view.php?LSobject=<?php echo rawurlencode($_smarty_tpl->tpl_vars['LSsearch']->value->LSobject);?>
&amp;page=<?php echo (isset($_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index']) ? $_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index'] : null);?>
'  class='LSobject-list-page'><?php echo (isset($_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index']) ? $_smarty_tpl->tpl_vars['__smarty_section_listpage']->value['index'] : null)+1;?>
</a>
      <?php }?>
    <?php
}
}
if ($__section_listpage_0_saved) {
$_smarty_tpl->tpl_vars['__smarty_section_listpage'] = $__section_listpage_0_saved;
}
?>
  <?php }?>
  </p>
<?php }
$_smarty_tpl->_subTemplateRender('ls:bottom.tpl', $_smarty_tpl->cache_id, $_smarty_tpl->compile_id, 0, $_smarty_tpl->cache_lifetime, array(), 0, false);
?>

<?php }
}
